/*
 * 这个代码，是展示如何使用本sdk的函数的示例代码，
 * 完整的API说明，可以直接在头文件中看到。
 * 建议本代码只作为参考示例，
 * 而不是复制到项目中直接使用。
 * */

#ifdef _WIN32
#define _CRT_SECURE_NO_WARNINGS
#include <windows.h>
#endif
#include <stdio.h>
#include <fstream>
#include <vector>
#include <chrono>
#include "wx_human_matting.h"
#include "wx_exception.h"

void test_remove_background(std::shared_ptr<wonxai::WXHumanMatting> &matting, const char* inputFile)
{
    printf("removeBackground testing...\n");
    auto inImg = wonxai::WXImage::fromFile(inputFile);
    auto bkImg = wonxai::WXImage::fromColor(inImg->width(), inImg->height(),
                                            255, 0,0); /* nullptr for a transparent background */
    auto t0 = std::chrono::system_clock::now();
    // 此处，bkImg初始化成红色背景图片，
    // 如果抠图后需要返回透明背景图，bkImg参数可以传入nullptr
    auto resImg = matting->removeBackground(inImg, bkImg);
    auto t1 = std::chrono::system_clock::now();
    std::chrono::duration<double> elapsed_time = t1 - t0;
    printf("removeBackground test ok, used_time: %.2f\n", elapsed_time.count());
    resImg->toFile("./res_bg.png");
    printf("save transparent background image to file ./res_bg.png \n\n");
}

int main(int argc, char *argv[])
{
    /*
     * 这个代码，是展示如何使用本sdk的函数的示例代码，
     * 完整的API说明，可以直接在头文件中看到。
     * 建议本代码只作为参考示例，
     * 而不是复制到项目中直接使用。
     * */
    const char *lic_file = "./my.lic";
    const WXDeviceType deviceType = kDeviceCPU; // kDeviceGPU
    std::shared_ptr<wonxai::WXHumanMatting> matting;

    int i;
    int n = 1;
  
    printf("sdk version: %s\n", wonxai::WXHumanMatting::version());
    
    try {
        wonxai::WXSDKInitWithLicense("你的appKey", lic_file);

        // 创建WXHumanMatting对象对象，用来做抠图处理（而不是用来做证件照处理）
        // 建议一个进程（或者线程）只创建一个WXHumanMatting对象，
        // 而不是每处理一张图片，都创建一个新的对象
        // 如果只是处理证件照业务（而不是抠图），则不需要本对象
        matting = std::make_shared<wonxai::WXHumanMatting>(deviceType);

    }
    catch (wonxai::WXException &e) {
        fprintf(stderr, "exception: %s\n", e.what());
        return -1;
    }

    try {
        // 对抠图接口，循环测试n次
        for (i = 0; i < n; i ++) {
            test_remove_background(matting, "./test.jpg");
        }

    }
    catch (wonxai::WXException &e) {
        fprintf(stderr, "exception: \n%s\n", e.what());
        return -1;
    }

    printf("test finish\n");

    return 0;
}
