/**
 * @file wx_exception.h
 * SDK异常定义
 */
#ifndef WX_EXCEPTION_H_
#define WX_EXCEPTION_H_

#include <iostream>
#include <exception>
#include <string>
#include "wx_api.h"

namespace wonxai {

/*! class WXException */
class WX_API WXException : public std::exception {
public:
    explicit WXException(int err_code, const char *fmt, ...) noexcept;
    ~WXException() noexcept override{};

    /**
     * @brief 获取异常错误码
     * @return 异常错误码
     */
    int errCode() const;

    /**
     * @brief 获取异常描述
     * @return 异常描述
     */
    const char* what() const noexcept override;

    /**
     * @brief 获取带错误码的异常描述
     * @return 异常描述
     */
    std::string toMsg();

protected:
    int err_code_;
    std::string message_;
};

}

#define WXRaiseExcept(errCode, msg, ...) throw wonxai::WXException(errCode, msg, ##__VA_ARGS__)

#endif //WX_EXCEPTION_H_

